@@ -101,7 +101,7 @@ def create_frame_graph(sdf: str) -> Tuple[Dict[str, rtf.Frame], Dict[str, rtf.Li
         :func:``skbot.ignition.to_frame_graph`` instead. To find frames in the
         frame graph returned by ``to_frame_graph`` use
         :func:``skbot.transform.Frame.find_frame``. Links/Joints can be obtained
-        from :func:``skbot.transform.Frame.transform_chain``.
+        from :func:``skbot.transform.Frame.links_between``.
 
     Parameters
     ----------
@@ -131,7 +131,8 @@ def create_frame_graph(sdf: str) -> Tuple[Dict[str, rtf.Frame], Dict[str, rtf.Li
         """create_frame_graph is deprecated and will be removed in skbot v1.0 in
         favor of to_frame_graph. Check the docs for detailed migration
         instructions.
-        """
+        """,
+        DeprecationWarning,
     )
 
     root = ElementTree.fromstring(sdf)
@@ -225,7 +226,7 @@ def create_frame_graph(sdf: str) -> Tuple[Dict[str, rtf.Frame], Dict[str, rtf.Li
         parent_frame = xpaths[parent]
         child_frame = xpaths[child]
         if np.any(pose[3:]) != 0:
-            rotated = rtf.EulerRotation("xyz", pose[3:])(child_frame)
+            rotated = rtf.EulerRotation("XYZ", pose[3:])(child_frame)
             rtf.Translation(pose[:3])(rotated, parent_frame)
         else:
             rtf.Translation(pose[:3])(child_frame, parent_frame)
